@@ -5,7 +5,7 @@ use 5.10.0;
 use strict;
 use warnings;
 
-our $VERSION = '0.02'; # TRIAL
+our $VERSION = '0.03'; # TRIAL
 
 use Carp;
 our @CARP_NOT = qw( Beam::Emitter );
@@ -476,15 +476,20 @@ sub __cb_unsubscribe {
 #pod
 #pod =cut
 
-sub DEMOLISH {
+sub DEMOLISH {}
+
+around DEMOLISH => sub {
+
+    my $orig = shift;
 
     my ( $self, $in_global_destruction ) = @_;
 
-    return if $in_global_destruction;
-
     # unsubscribe from network
-    $self->unsubscribe;
-}
+    $self->unsubscribe
+	unless $in_global_destruction;
+
+    &$orig;
+};
 
 
 1;
@@ -507,7 +512,7 @@ Net::Object::Peer - Peer-to-Peer Publish/Subscribe Network of Objects
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
